@@ -14,6 +14,8 @@ Usage::
         ListFeaturesPaginator,
         ListLaunchesPaginator,
         ListProjectsPaginator,
+        ListSegmentReferencesPaginator,
+        ListSegmentsPaginator,
     )
 
     session = Session()
@@ -23,19 +25,22 @@ Usage::
     list_features_paginator: ListFeaturesPaginator = client.get_paginator("list_features")
     list_launches_paginator: ListLaunchesPaginator = client.get_paginator("list_launches")
     list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
+    list_segment_references_paginator: ListSegmentReferencesPaginator = client.get_paginator("list_segment_references")
+    list_segments_paginator: ListSegmentsPaginator = client.get_paginator("list_segments")
     ```
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
-from .literals import ExperimentStatusType, LaunchStatusType
+from .literals import ExperimentStatusType, LaunchStatusType, SegmentReferenceResourceTypeType
 from .type_defs import (
     ListExperimentsResponseTypeDef,
     ListFeaturesResponseTypeDef,
     ListLaunchesResponseTypeDef,
     ListProjectsResponseTypeDef,
+    ListSegmentReferencesResponseTypeDef,
+    ListSegmentsResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -44,6 +49,8 @@ __all__ = (
     "ListFeaturesPaginator",
     "ListLaunchesPaginator",
     "ListProjectsPaginator",
+    "ListSegmentReferencesPaginator",
+    "ListSegmentsPaginator",
 )
 
 
@@ -57,7 +64,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListExperimentsPaginator(Boto3Paginator):
+class ListExperimentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListExperiments)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_evidently/paginators/#listexperimentspaginator)
@@ -76,7 +83,7 @@ class ListExperimentsPaginator(Boto3Paginator):
         """
 
 
-class ListFeaturesPaginator(Boto3Paginator):
+class ListFeaturesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListFeatures)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_evidently/paginators/#listfeaturespaginator)
@@ -91,7 +98,7 @@ class ListFeaturesPaginator(Boto3Paginator):
         """
 
 
-class ListLaunchesPaginator(Boto3Paginator):
+class ListLaunchesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListLaunches)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_evidently/paginators/#listlaunchespaginator)
@@ -110,7 +117,7 @@ class ListLaunchesPaginator(Boto3Paginator):
         """
 
 
-class ListProjectsPaginator(Boto3Paginator):
+class ListProjectsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListProjects)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_evidently/paginators/#listprojectspaginator)
@@ -123,3 +130,37 @@ class ListProjectsPaginator(Boto3Paginator):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListProjects.paginate)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_evidently/paginators/#listprojectspaginator)
         """
+
+
+class ListSegmentReferencesPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListSegmentReferences)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_evidently/paginators/#listsegmentreferencespaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        segment: str,
+        type: SegmentReferenceResourceTypeType,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListSegmentReferencesResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListSegmentReferences.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_evidently/paginators/#listsegmentreferencespaginator)
+        """
+
+
+class ListSegmentsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListSegments)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_evidently/paginators/#listsegmentspaginator)
+    """
+
+    def paginate(
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListSegmentsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListSegments.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_evidently/paginators/#listsegmentspaginator)
+        """
